Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DiscoveryOptions ¶ added in v1.23.0
type DiscoveryOptions struct {
// Enabled specifies whether support for discovery population is enabled.
Enabled bool `json:"enabled"`
}
DiscoveryOptions configures our support for discovery, particularly gossip DNS (i.e. k8s.local)
type Options ¶
type Options struct {
Cloud string `json:"cloud,omitempty"`
ConfigBase string `json:"configBase,omitempty"`
Server *ServerOptions `json:"server,omitempty"`
CacheNodeidentityInfo bool `json:"cacheNodeidentityInfo,omitempty"`
// EnableCloudIPAM enables the cloud IPAM controller.
EnableCloudIPAM bool `json:"enableCloudIPAM,omitempty"`
// Discovery configures options relating to discovery, particularly for gossip mode.
Discovery *DiscoveryOptions `json:"discovery,omitempty"`
}
func (*Options) PopulateDefaults ¶
func (o *Options) PopulateDefaults()
type ServerOptions ¶ added in v1.19.0
type ServerOptions struct {
// Listen is the network endpoint (ip and port) we should listen on.
Listen string
// Provider is the cloud provider.
Provider ServerProviderOptions `json:"provider"`
// ServerKeyPath is the path to our TLS serving private key.
ServerKeyPath string `json:"serverKeyPath,omitempty"`
// ServerCertificatePath is the path to our TLS serving certificate.
ServerCertificatePath string `json:"serverCertificatePath,omitempty"`
// CABasePath is a base of the path to CA certificate and key files.
CABasePath string `json:"caBasePath"`
// SigningCAs is the list of active signing CAs.
SigningCAs []string `json:"signingCAs"`
// CertNames is the list of active certificate names.
CertNames []string `json:"certNames"`
// UseInstanceIDForNodeName uses the instance ID instead of the hostname for the node name.
UseInstanceIDForNodeName bool `json:"useInstanceIDForNodeName,omitempty"`
}
type ServerProviderOptions ¶ added in v1.19.0
type ServerProviderOptions struct {
AWS *awsup.AWSVerifierOptions `json:"aws,omitempty"`
GCE *gcetpm.TPMVerifierOptions `json:"gce,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.